<?php
/*
Plugin Name: FocalPoint
Plugin URI: https://www.fbnfrtg.de/
Description: Definiere den Fokuspunkt des Beitragsbildes.
Version: 1.0
Author: Fabian Freitag
Author URI: https://www.fbnfrtg.de/
*/

function add_focal_point_field() {
    add_meta_box(
        'focal_point_meta_box',
        'Fokuspunkt',
        'render_focal_point_field',
        'post',
        'side',
        'low'
    );
}
add_action('add_meta_boxes', 'add_focal_point_field');

function render_focal_point_field($post) {
    $focal_point = get_post_meta($post->ID, 'focal_point', true);

    $thumbnail_id = get_post_thumbnail_id($post->ID);
    $thumbnail_url = wp_get_attachment_image_src($thumbnail_id, 'large');
    if ($thumbnail_url) {
?>
   
    <div style="position: relative; overflow:hidden; padding-bottom:5px;">
    <img id="focal_point_image" src="<?php echo esc_attr($thumbnail_url[0]); ?>" style="max-width: 100%; height: auto;" />
    <div id="focal_point_marker"></div>
    </div>
    <p>Klicke auf das Bild, um den Fokuspunkt zu setzen.</p>
    
    <input type="hidden" id="focal_point_x" name="focal_point_x" value="<?php echo esc_attr($focal_point['x'] ?? ''); ?>" />
    <input type="hidden" id="focal_point_y" name="focal_point_y" value="<?php echo esc_attr($focal_point['y'] ?? ''); ?>" />
        
    <style>
        #focal_point_marker {
            position: absolute;
            width: 10px;
            height: 10px;
            background-color: white;
            border-radius: 50%;
            pointer-events: none;
            display: none;
            transform:translate(-5px,-5px);
            box-shadow:0 0 4px rgba(0,0,0,0.6);

        }
    </style>

        <script>
            jQuery(function ($) {
            var marker = $('#focal_point_marker');

            var x = <?php echo intval($focal_point['x'] ?? 0); ?>;
            var y = <?php echo intval($focal_point['y'] ?? 0); ?>;
            marker.css({ left: x +'%', top: y +'%' }).show();
            

            $('#focal_point_image').on('click', function (event) {
                var img = $(this);
                var offset = img.offset();
                var width = img.width();
                var height = img.height();
                var x = ((event.pageX - offset.left) / width).toFixed(4)*100;
                var y = ((event.pageY - offset.top) / height).toFixed(4)*100;
                
                $('#focal_point_x').val(x);
                $('#focal_point_y').val(y);
               
                var marker_x = event.pageX - offset.left;
                var marker_y = event.pageY - offset.top;
                updateMarkerPosition(marker_x, marker_y);
                
            });

            function updateMarkerPosition(marker_x, marker_y) {
                marker.css({ left: marker_x +'px', top: marker_y +'px' }).show();
            }
        });
        </script>
        <?php
    }
}

function save_focal_point_data($post_id) {
    if (!current_user_can('edit_post', $post_id)) {
        return;
    }

    if (!isset($_POST['focal_point_x']) || !isset($_POST['focal_point_y'])) {
        return;
    }

    $focal_point = array(
        'x' => sanitize_text_field($_POST['focal_point_x']),
        'y' => sanitize_text_field($_POST['focal_point_y'])
    );
    update_post_meta($post_id, 'focal_point', $focal_point);
}
add_action('save_post', 'save_focal_point_data');
